@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert chords to Roman numeral notation
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0200';
 
 use Moo;
 use strictures 2;
@@ -68,6 +68,12 @@ sub parse {
     # Drop the minor and major part of the chord name
     $decorator =~ s/M//i;
 
+    if ( $decorator =~ /([A-G])/ ) {
+        my $letter = $1;
+        $position = first_index { $_ eq $letter } @notes;
+        $decorator =~ s/[A-G]/$roman[$position]/;
+    }
+
     # Append the remaining decorator to the roman representation
     $roman .= $decorator;
 
@@ -88,7 +94,7 @@ Music::ToRoman - Convert chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.0101
+version 0.0200
 
 =head1 SYNOPSIS
 
